@@ -5,14 +5,15 @@
 using System;
 using System.IO;
 
-namespace FSpot {
+using FSpot.Utils;
+using Hyena;
 
-	public delegate void OrientationChangedHandler (object sender);
+namespace FSpot {
 
 	public class Accelerometer {
 		public const string SYSFS_FILE = "/sys/devices/platform/hdaps/position";
 
-		public static event OrientationChangedHandler OrientationChanged;
+		public static event EventHandler OrientationChanged;
 
 		public enum Orient {
 			Normal,
@@ -22,7 +23,7 @@ namespace FSpot {
 
 		private static Orient current_orientation;
 
-		public Orient CurrentOrientation {
+		public static Orient CurrentOrientation {
 			get {
 				return current_orientation;
 			}
@@ -38,10 +39,10 @@ namespace FSpot {
 				SetupAccelerometer ();
 				
 			if (current_orientation == Orient.TiltCounterclockwise)
-				return PixbufUtils.Rotate90 (po);
+				return FSpot.Utils.PixbufUtils.Rotate90 (po);
 
 			if (current_orientation == Orient.TiltClockwise)
-				return PixbufUtils.Rotate270 (po);
+				return FSpot.Utils.PixbufUtils.Rotate270 (po);
 
 			return po;
 		}
@@ -73,10 +74,11 @@ namespace FSpot {
 			if (new_orient != current_orientation) {
 				current_orientation = new_orient;
 
-				if (OrientationChanged != null)
-					OrientationChanged (null);
+				EventHandler eh = OrientationChanged;
+				if (eh != null)
+					eh (null, EventArgs.Empty);
 
-				Console.WriteLine ("Laptop orientation changed...");
+				Log.Debug ("Laptop orientation changed...");
 			}
 
 			return true;
