@@ -1,54 +1,34 @@
 using System.Threading;
 using System.Collections;
+using System.Collections.Generic;
 using System.IO;
 using System;
 using Banshee.Database;
 using System.Diagnostics;
 using FSpot;
-
-public class DbItemEventArgs {
-	private DbItem [] items;
-	
-	public DbItem [] Items {
-		get { return items; }
-	}
-	
-	public DbItemEventArgs (DbItem [] items)
-	{
-		this.items = items;
-	}
-	
-	public DbItemEventArgs (DbItem item)
-	{
-		this.items = new DbItem [] { item };
-	}
-}
+using Hyena;
 
 // A Store maps to a SQL table.  We have separate stores (i.e. SQL tables) for tags, photos and imports.
 
-public delegate void ItemsAddedHandler (object sender, DbItemEventArgs args);
-public delegate void ItemsRemovedHandler (object sender, DbItemEventArgs args);
-public delegate void ItemsChangedHandler (object sender, DbItemEventArgs args);
-
 public class DbException : ApplicationException {
 	public DbException(string msg) : base(msg)
 	{
 	}
 }
 
-public abstract class DbStore {
+public abstract class DbStore<T> where T : DbItem {
 	// DbItem cache.
 
-	public event ItemsAddedHandler   ItemsAdded;
-	public event ItemsRemovedHandler ItemsRemoved;
-	public event ItemsChangedHandler ItemsChanged;
+	public event EventHandler<DbItemEventArgs<T>> ItemsAdded;
+	public event EventHandler<DbItemEventArgs<T>> ItemsRemoved;
+	public event EventHandler<DbItemEventArgs<T>> ItemsChanged;
 
-	protected Hashtable item_cache;
+	protected Dictionary<uint, object> item_cache;
 	bool cache_is_immortal;
 
-	protected void AddToCache (DbItem item)
+	protected void AddToCache (T item)
 	{
-		if (item_cache.Contains (item.Id))
+		if (item_cache.ContainsKey (item.Id))
 			item_cache.Remove (item.Id);
 
 		if (cache_is_immortal)
@@ -57,59 +37,59 @@ public abstract class DbStore {
 			item_cache.Add (item.Id, new WeakReference (item));
 	}
 
-	protected DbItem LookupInCache (uint id)
+	protected T LookupInCache (uint id)
 	{
+		if (!item_cache.ContainsKey(id))
+			return null;
+
 		if (cache_is_immortal)
-			return item_cache [id] as DbItem;
+			return item_cache [id] as T;
 
 		WeakReference weakref = item_cache [id] as WeakReference;
-		if (weakref == null)
-			return null;
-		else
-			return (DbItem) weakref.Target;
+		return (T) weakref.Target;
 	}
 
-	protected void RemoveFromCache (DbItem item)
+	protected void RemoveFromCache (T item)
 	{
 		item_cache.Remove (item.Id);
 	}
 
-	protected void EmitAdded (DbItem item)
+	protected void EmitAdded (T item)
 	{
-		EmitAdded (new DbItem [] { item });
+		EmitAdded (new T [] { item });
 	}
 
-	protected void EmitAdded (DbItem [] items)
+	protected void EmitAdded (T [] items)
 	{
 		if (ItemsAdded != null)
-			ItemsAdded (this, new DbItemEventArgs (items));
+			ItemsAdded (this, new DbItemEventArgs<T> (items));
 	}
 
-	protected void EmitChanged (DbItem item)
+	protected void EmitChanged (T item)
 	{
-		EmitChanged (new DbItem [] { item });
+		EmitChanged (new T [] { item });
 	}
 
-	protected void EmitChanged (DbItem [] items)
+	protected void EmitChanged (T [] items)
 	{
-		EmitChanged (items, new DbItemEventArgs (items));
+		EmitChanged (items, new DbItemEventArgs<T> (items));
 	}
 
-	protected void EmitChanged (DbItem [] items, DbItemEventArgs args)
+	protected void EmitChanged (T [] items, DbItemEventArgs<T> args)
 	{
 		if (ItemsChanged != null)
 			ItemsChanged (this, args);
 	}
 
-	protected void EmitRemoved (DbItem item)
+	protected void EmitRemoved (T item)
 	{
-		EmitRemoved (new DbItem [] { item });
+		EmitRemoved (new T [] { item });
 	}
 
-	protected void EmitRemoved (DbItem [] items)
+	protected void EmitRemoved (T [] items)
 	{
 		if (ItemsRemoved != null)
-			ItemsRemoved (this, new DbItemEventArgs (items));
+			ItemsRemoved (this, new DbItemEventArgs<T> (items));
 	}
 
 	public bool CacheEmpty {
@@ -135,17 +115,17 @@ public abstract class DbStore {
 		this.database = database;
 		this.cache_is_immortal = cache_is_immortal;
 
-		item_cache = new Hashtable ();
+		item_cache = new Dictionary<uint, object> ();
 	}
 
 
 	// Abstract methods.
 
-	public abstract DbItem Get (uint id);
-	public abstract void Remove (DbItem item);
+	public abstract T Get (uint id);
+	public abstract void Remove (T item);
 	// If you have made changes to "obj", you have to invoke Commit() to have the changes
 	// saved into the database.
-	public abstract void Commit (DbItem item);
+	public abstract void Commit (T item);
 }
 
 
@@ -162,6 +142,10 @@ public class Db : IDisposable {
 	bool empty;
 	string path;
 
+	public delegate void ExceptionThrownHandler (Exception e);
+	public event ExceptionThrownHandler ExceptionThrown;
+
+
 	public TagStore Tags {
 		get { return tag_store; }
 	}
@@ -222,6 +206,7 @@ public class Db : IDisposable {
 
 	public void Init (string path, bool create_if_missing)
 	{
+		uint timer = Log.DebugTimerStart ();
 		bool new_db = ! File.Exists (path);
 		this.path = path;
 
@@ -229,6 +214,8 @@ public class Db : IDisposable {
 			throw new Exception (path + ": File not found");
 
 		database = new QueuedSqliteDatabase(path);
+		database.ExceptionThrown += HandleDbException;
+
 		if (database.GetFileVersion(path) == 2)
 			SqliteUpgrade ();
 
@@ -236,7 +223,7 @@ public class Db : IDisposable {
  		meta_store = new MetaStore (Database, new_db);
 
 		// Update the database schema if necessary
-		FSpot.Database.Updater.Run (this);
+		FSpot.Database.Updater.Run (Database);
 
 		Database.BeginTransaction ();
 
@@ -246,15 +233,18 @@ public class Db : IDisposable {
 		job_store = new JobStore (Database, new_db);
  		photo_store = new PhotoStore (Database, new_db);
 
-		FSpot.DBusProxyFactory.Load (this);
-		
 		Database.CommitTransaction ();
 
 		empty = new_db;
+		Log.DebugTimerPrint (timer, "Db Initialization took {0}");
 	}
 
-	public void EmitDown () {
-		FSpot.DBusProxyFactory.EmitRemoteDown ();
+	void HandleDbException (Exception e)
+	{
+		if (ExceptionThrown != null)
+			ExceptionThrown (e);
+		else
+			throw e;
 	}
 
 	public bool Empty {
@@ -265,7 +255,27 @@ public class Db : IDisposable {
 
 	public void Dispose ()
 	{
-		Database.Dispose ();
+		Dispose (true);
+		GC.SuppressFinalize (this);
+	}
+
+	bool already_disposed = false;
+	protected virtual void Dispose (bool is_disposing)
+	{
+		if (already_disposed)
+			return;
+		if (is_disposing) {//Free managed resources
+			Database.Dispose ();
+		}
+		//Free eunmanaged resources
+
+		already_disposed = true;
+	}
+
+	~Db ()
+	{
+		Log.DebugFormat ("Finalizer called on {0}. Should be Disposed", GetType ());
+		Dispose (false);
 	}
 
 	public void BeginTransaction()
@@ -305,7 +315,7 @@ public class Db : IDisposable {
 		if (upgrader_path == null)
 			throw new DbException ("Failed to upgrade the f-spot sqlite2 database to sqlite3!\n" + "Unable to find the f-spot-sqlite-upgrade script on your system");
 
-		Console.WriteLine ("Running {0}...", upgrader_path);
+		Log.DebugFormat ("Running {0}...", upgrader_path);
 		ProcessStartInfo updaterInfo = new ProcessStartInfo (upgrader_path);
 		updaterInfo.UseShellExecute = false;
 		updaterInfo.RedirectStandardError = true;
