@@ -11,7 +11,8 @@ using System;
 using Gtk;
 using Gdk;
 using FSpot.Widgets;
-using Cairo;
+using FSpot.Utils;
+using Hyena;
 using Mono.Unix;
 
 namespace FSpot {
@@ -19,12 +20,13 @@ namespace FSpot {
 	public class FullScreenView : Gtk.Window {
 		private ScrolledView scroll;
 		private PhotoImageView view;
-		private TagView tag_view;
 		private Notebook notebook;
 		private ControlOverlay controls;
 		//		private ImageDisplay display;
-		private TextureDisplay display;
+		private SlideShow display;
 		private ToolButton play_pause_button;
+		private ToggleToolButton info_button;
+		private Delay hide_cursor_delay;
 
 		ActionGroup actions;
 		const string ExitFullScreen = "ExitFullScreen";
@@ -32,8 +34,14 @@ namespace FSpot {
 		const string SlideShow = "SlideShow";
 		const string Info = "Info";
 		
-		public FullScreenView (IBrowsableCollection collection) : base ("Full Screen Mode")
+		public FullScreenView (IBrowsableCollection collection, Gtk.Window parent) : base ("Full Screen Mode")
 		{
+			//going fullscreen on the same screen the parent window
+			Gdk.Screen screen = Screen;
+			int monitor = screen.GetMonitorAtWindow (parent.GdkWindow);
+			Gdk.Rectangle bounds = screen.GetMonitorGeometry (monitor);
+			Move (bounds.X, bounds.Y);
+
 			string style = "style \"test\" {\n" +
 				"GtkToolbar::shadow_type = GTK_SHADOW_NONE\n" +
 				"}\n" +
@@ -62,27 +70,23 @@ namespace FSpot {
 							       InfoAction,
 							       false)});
 
-				Action exit_full_screen = new Action (ExitFullScreen, 
+				Gtk.Action exit_full_screen = new Gtk.Action (ExitFullScreen, 
 					Catalog.GetString ("Exit fullscreen"),
 					null,
 					null);
-#if GTK_2_10
 				exit_full_screen.IconName = "view-restore";
-#endif
 				exit_full_screen.Activated += ExitAction;
 				actions.Add (exit_full_screen);
 
-				Action slide_show = new Action (SlideShow,
+				Gtk.Action slide_show = new Gtk.Action (SlideShow,
 					Catalog.GetString ("Slideshow"),
 					Catalog.GetString ("Start slideshow"),
 					null);
-#if GTK_2_10
 				slide_show.IconName = "media-playback-start";
-#endif
 				slide_show.Activated += SlideShowAction;
 				actions.Add (slide_show);
 
-				new Fader (this, 1.0, 3);
+				new Fader (this, 1.0, 600);
 				notebook = new Notebook ();
 				notebook.ShowBorder = false;
 				notebook.ShowTabs = false;
@@ -93,10 +97,10 @@ namespace FSpot {
 				view = new PhotoImageView (collection);
 				// FIXME this should be handled by the new style setting code
 				view.ModifyBg (Gtk.StateType.Normal, this.Style.Black);
-				view.PointerMode = ImageView.PointerModeType.Scroll;
 				this.Add (notebook);
 				view.Show ();
 				view.MotionNotifyEvent += HandleViewMotion;
+				view.PointerMode = PointerMode.Scroll;
 				
 				scroll.ScrolledWindow.Add (view);
 
@@ -110,74 +114,46 @@ namespace FSpot {
 				t_item.IsImportant = true;
 				tbar.Insert (t_item, -1);
 
-				Action action = new PreviousPictureAction (view.Item);
+				Gtk.Action action = new PreviousPictureAction (view.Item);
 				actions.Add (action);
-#if GTK_2_10
 				tbar.Insert (action.CreateToolItem () as ToolItem, -1);
-#else
-				t_item = action.CreateToolItem () as ToolItem;
-				(t_item as ToolButton).IconName = "gtk-go-back-ltr"; 
-				tbar.Insert (t_item, -1);
-#endif
 
 				play_pause_button = (actions [SlideShow]).CreateToolItem () as ToolButton;
-#if GTK_2_10
 				tbar.Insert (play_pause_button, -1);
-#else
-				play_pause_button.IconName = "media-playback-start";
-				tbar.Insert (play_pause_button, -1);
-#endif
 
 				action = new NextPictureAction (view.Item);
 				actions.Add (action);
-#if GTK_2_10
 				tbar.Insert (action.CreateToolItem () as ToolItem, -1);
-#else
-				t_item = action.CreateToolItem () as ToolItem;
-				(t_item as ToolButton).IconName = "gtk-go-forward-ltr"; 
-				tbar.Insert (t_item, -1);
-#endif
 
 				t_item = new ToolItem ();
-				t_item.Child = new Label (Catalog.GetString ("Slide transition: "));
+				t_item.Child = new Label (Catalog.GetString ("Slide transition:"));
 				tbar.Insert (t_item, -1);
 
-				display = new TextureDisplay (view.Item);
+				display = new SlideShow (view.Item);
 				display.AddEvents ((int) (Gdk.EventMask.PointerMotionMask));
 				display.ModifyBg (Gtk.StateType.Normal, this.Style.Black);
 				display.MotionNotifyEvent += HandleViewMotion;
 				display.Show ();
 
 				t_item = new ToolItem ();
-				t_item.Child = display.GetCombo ();
+				ComboBox combo = ComboBox.NewText ();
+				foreach (var transition in display.Transitions)
+					combo.AppendText (transition.Name);
+				combo.Active = 0;
+				combo.Changed += HandleTransitionChanged;
+				t_item.Child = combo;
 				tbar.Insert (t_item, -1);
 
 				action = new RotateLeftAction (view.Item);
 				actions.Add (action);
-#if GTK_2_10
 				tbar.Insert (action.CreateToolItem () as ToolItem, -1);
-#else
-				t_item = action.CreateToolItem () as ToolItem;
-				(t_item as ToolButton).IconName = "object-rotate-left"; 
-				tbar.Insert (t_item, -1);
-#endif
 
 				action = new RotateRightAction (view.Item);
 				actions.Add (action);
-#if GTK_2_10
 				tbar.Insert (action.CreateToolItem () as ToolItem, -1);
-#else
-				t_item = action.CreateToolItem () as ToolItem;
-				(t_item as ToolButton).IconName = "object-rotate-right"; 
-				tbar.Insert (t_item, -1);
-#endif
 
-				tag_view = new TagView ();
-				t_item = new ToolItem ();
-				t_item.Child = tag_view;
-				tbar.Insert (t_item, -1);
-
-				tbar.Insert ((actions [Info]).CreateToolItem () as ToolItem, -1);
+				info_button = (ToggleToolButton) ((actions [Info]).CreateToolItem () as ToolItem);
+				tbar.Insert (info_button, -1);
 
 				tbar.Insert ((actions [HideToolbar]).CreateToolItem () as ToolItem, -1);
 
@@ -193,6 +169,9 @@ namespace FSpot {
 				
 				view.Item.Changed += HandleItemChanged;
 				view.GrabFocus ();
+
+				hide_cursor_delay = new Delay (3000, new GLib.IdleHandler (HideCursor));
+				hide_cursor_delay.Start ();
 				
 				controls = new ControlOverlay (this);
 				controls.Add (tbar);
@@ -200,38 +179,67 @@ namespace FSpot {
 
 				notebook.CurrentPage = 0;
 			} catch (System.Exception e) {
-				System.Console.WriteLine (e);
+				Log.Exception (e);
 			}	
-
 		}
 
-		private void HandleItemChanged (object sender, BrowsablePointerChangedArgs args)
+		private Gdk.Cursor empty_cursor;
+		private bool HideCursor ()
+		{
+			if (view.Panning) {
+				return false;
+			}
+
+			if (empty_cursor == null) 
+				empty_cursor = GdkUtils.CreateEmptyCursor (GdkWindow.Display);
+			
+			this.GdkWindow.Cursor = empty_cursor;
+			view.GdkWindow.Cursor = empty_cursor;
+			return false;
+		}
+		
+		private void ShowCursor () 
+		{
+			view.PointerMode = PointerMode.Scroll;
+			this.GdkWindow.Cursor = null;
+		}
+		
+		private void HandleItemChanged (object sender, BrowsablePointerChangedEventArgs args)
 		{
-			tag_view.Current = view.Item.Current;
 			if (scroll.ControlBox.Visible)
 				scroll.ShowControls ();
 		}
-#if false
+
+		void HandleTransitionChanged (object sender, EventArgs e)
+		{
+			ComboBox combo = sender as ComboBox;
+			if (combo == null)
+				return;
+			TreeIter iter;
+			if (combo.GetActiveIter (out iter)) {
+				string name = combo.Model.GetValue (iter, 0) as string;
+				foreach (var transition in display.Transitions)
+					if (transition.Name == name)
+						display.Transition = transition;
+			}
+
+
+		}
+
 		protected override bool OnExposeEvent (Gdk.EventExpose args)
 		{
 			bool ret = base.OnExposeEvent (args);
-			Graphics g = CairoUtils.CreateDrawable (GdkWindow);
-
-			g.Color = new Cairo.Color (0, 0, 0, .5);
-			g.Operator = Operator.DestOut;
-			g.Rectangle (0, 0, Allocation.Width  * .5, Allocation.Height);
-			g.Paint ();
 
+			HideCursor ();
 			return ret;
 		}
-#endif
 		
 		private void ExitAction (object sender, System.EventArgs args)
 		{
-			this.Destroy ();
+			Quit ();
 		}
 
-	        private void HideToolbarAction (object sender, System.EventArgs args)
+		private void HideToolbarAction (object sender, System.EventArgs args)
 		{
 			scroll.HideControls (true);
 			controls.Dismiss ();
@@ -245,13 +253,18 @@ namespace FSpot {
 		InfoOverlay info;
 		private void InfoAction (object sender, System.EventArgs args)
 		{
-			ToggleAction action = sender as ToggleAction;
+			bool active = false;
+			if (sender is ToggleToolButton) {
+				(sender as ToggleToolButton).Active = ! (sender as ToggleToolButton).Active;
+				active = (sender as ToggleToolButton).Active;
+			} else 
+				active = (sender as ToggleAction).Active;
 
 			if (info == null) {
 				info = new InfoOverlay (this, view.Item);
 			}
 
-			info.Visibility = action.Active ? 
+			info.Visibility = active ? 
 				ControlOverlay.VisibilityType.Partial : 
 				ControlOverlay.VisibilityType.None;
 		}
@@ -259,11 +272,17 @@ namespace FSpot {
 		[GLib.ConnectBefore]
 		private void HandleViewMotion (object sender, Gtk.MotionNotifyEventArgs args)
 		{
+			ShowCursor ();
+			hide_cursor_delay.Restart ();
+			
 			int x, y;
 			Gdk.ModifierType type;
 			((Gtk.Widget)sender).GdkWindow.GetPointer (out x, out y, out type);
-			controls.Visibility = ControlOverlay.VisibilityType.Partial;
-			scroll.ShowControls ();
+
+			if (y > (Allocation.Height * 0.75)) {
+				controls.Visibility = ControlOverlay.VisibilityType.Partial;
+				scroll.ShowControls ();
+			}
 		}
 
 		public PhotoImageView View {
@@ -276,7 +295,7 @@ namespace FSpot {
 		{
 			if (args.Event.Type == Gdk.EventType.ButtonPress
 			    && args.Event.Button == 3) {
-				PhotoPopup popup = new PhotoPopup ();
+				PhotoPopup popup = new PhotoPopup (this);
 				popup.Activate (this.Toplevel, args.Event);
 			}
 		}
@@ -284,12 +303,12 @@ namespace FSpot {
 		public bool PlayPause ()
 		{
 			if (notebook.CurrentPage == 0) {
-				FSpot.Utils.ScreenSaver.Inhibit ("Running slideshow mode");
+				FSpot.Platform.ScreenSaver.Inhibit ("Running slideshow mode");
 				notebook.CurrentPage = 1;
 				play_pause_button.IconName = "media-playback-pause";
 				display.Start ();
 			} else {
-				FSpot.Utils.ScreenSaver.UnInhibit ();
+				FSpot.Platform.ScreenSaver.UnInhibit ();
 				notebook.CurrentPage = 0;
 				play_pause_button.IconName = "media-playback-start";
 				display.Stop ();
@@ -299,45 +318,38 @@ namespace FSpot {
 
 		public void Quit ()
 		{
-			FSpot.Utils.ScreenSaver.UnInhibit ();
+			hide_cursor_delay.Stop ();
+			FSpot.Platform.ScreenSaver.UnInhibit ();
+
 			this.Destroy ();
 		}
 
 		protected override bool OnKeyPressEvent (Gdk.EventKey key)
 		{
 			switch (key.Key) {
-				case Gdk.Key.Up:
-				case Gdk.Key.Left:
-				case Gdk.Key.KP_Up:
-				case Gdk.Key.KP_Left:
-				case Gdk.Key.Page_Up:
-				case Gdk.Key.Down:
-				case Gdk.Key.Right:
-				case Gdk.Key.KP_Down:
-				case Gdk.Key.KP_Right:
-				case Gdk.Key.Page_Down:
-					break;
-				default:
-					controls.Visibility = ControlOverlay.VisibilityType.Partial;
-					break;
-			}
-
-			if (key == null) {
-				System.Console.WriteLine ("Key == null", key);
-				return false;
-			}
-
-			if (view == null) {
-				System.Console.WriteLine ("view == null", key);
-				return false;
-			}
-
-			bool retval = base.OnKeyPressEvent (key);
-			if (!retval)
+			// quit only on certain keys
+			case Gdk.Key.F:
+			case Gdk.Key.f:
+			case Gdk.Key.Q:
+			case Gdk.Key.q:
+			case Gdk.Key.F11:
+			case Gdk.Key.Escape:
 				Quit ();
-			else 
-				view.Fit = false;
-			return retval;
+				return true;
+			// display infobox for 'i' key
+			case Gdk.Key.i:
+			case Gdk.Key.I:
+				InfoAction (info_button, null);
+				return true;
+			case Gdk.Key.bracketleft:
+				new RotateLeftAction (view.Item).Activate ();
+				return true;
+			case Gdk.Key.bracketright:
+				new RotateRightAction (view.Item).Activate ();
+				return true;
+			}
+
+			return base.OnKeyPressEvent (key);
 		}
 	}
 }
