@@ -26,15 +26,13 @@ namespace FSpot {
 				   string icon_name) : base (name, label)
 		{
 			Tooltip = tooltip;
-#if GTK_2_10
 			IconName = icon_name;
-#endif
 			item = pointer;
 			item.Changed += ItemChanged;
 		}
 
-	        protected virtual void ItemChanged (BrowsablePointer sender, 
-						    BrowsablePointerChangedArgs args)
+	        protected virtual void ItemChanged (object sender, 
+						    BrowsablePointerChangedEventArgs args)
 		{
 			Sensitive = item.IsValid;
 		}
@@ -107,8 +105,7 @@ namespace FSpot {
 		{
 		}
 
-		protected override void ItemChanged (BrowsablePointer p,
-						     BrowsablePointerChangedArgs args)
+		protected override void ItemChanged (object sender, BrowsablePointerChangedEventArgs args)
 		{
 			Sensitive = item.Index < item.Collection.Count -1;
 		}
@@ -129,8 +126,7 @@ namespace FSpot {
 		{
 		}
 
-		protected override void ItemChanged (BrowsablePointer p,
-						     BrowsablePointerChangedArgs args)
+		protected override void ItemChanged (object sender, BrowsablePointerChangedEventArgs args)
 		{
 			Sensitive =  item.Index > 0;
 		}
