@@ -2,11 +2,12 @@ using SemWeb;
 using SemWeb.Util;
 using Mono.Unix;
 using FSpot.Xmp;
+using FSpot.Utils;
+using Hyena;
 
 namespace FSpot {
         internal class Description {
 		string predicate;
-		string description;
 		string title;
 		ValueFormat formater;
 		
@@ -21,6 +22,10 @@ namespace FSpot {
 				new Description ("dc:subject", Catalog.GetString ("Subject and Keywords")),
 				new Description ("tiff:Compression", Catalog.GetString ("Compression"), 
 						 typeof (FSpot.Tiff.Compression)),
+						 /* Translators: Planar Configuration is the label for the tiff:PlanarConfiguration tag
+						    "when Planar Configuration=1, this implies that all components must have
+						    the same BitsPerSample value; when Planar Configuration=2, different
+						    components could have different bit depths." */
 				new Description ("tiff:PlanarConfiguration", Catalog.GetString ("Planar Configuration"), 
 						 typeof (FSpot.Tiff.PlanarConfiguration)),
 				new Description ("tiff:Orientation", Catalog.GetString ("Orientation"), 
@@ -53,6 +58,8 @@ namespace FSpot {
 						 typeof (FSpot.Tiff.FileSource)),
 				new Description ("exif:SceneCaptureType", Catalog.GetString ("Scene Capture Type"),
 						 typeof (FSpot.Tiff.SceneCaptureType)),
+						 /* Translators: Gain Control is the label for the exif:GainControl tag
+						    "This tag indicates the degree of overall image gain adjustment." */
 				new Description ("exif:GainControl", Catalog.GetString ("Gain Control"),
 						 typeof (FSpot.Tiff.GainControl)),
 				new Description ("exif:Contrast", Catalog.GetString ("Contrast"),
@@ -100,13 +107,13 @@ namespace FSpot {
 			label = System.IO.Path.GetFileName (predicate);
 			value = null;
 
-			if (stmt.Object is Literal)
-			        value = ((Literal)(stmt.Object)).Value;
+			if (stmt.Object is SemWeb.Literal)
+			        value = ((SemWeb.Literal)(stmt.Object)).Value;
 
 			if (d != null) {
 				label = d.title;
-				if (d.formater != null && stmt.Object is Literal)
-					value = d.formater.GetValue (store, (Literal)stmt.Object);
+				if (d.formater != null && stmt.Object is SemWeb.Literal)
+					value = d.formater.GetValue (store, (SemWeb.Literal)stmt.Object);
 
 			} else {
 				Statement sstmt = new Statement (stmt.Predicate,
@@ -114,8 +121,8 @@ namespace FSpot {
 								 null);
 				
 				foreach (Statement tstmt in MetadataStore.Descriptions.Select (sstmt))
-					if (tstmt.Object is Literal)
-						label = ((Literal)(tstmt.Object)).Value;
+					if (tstmt.Object is SemWeb.Literal)
+						label = ((SemWeb.Literal)(tstmt.Object)).Value;
 			}
 			return;
 		}
@@ -130,7 +137,7 @@ namespace FSpot {
 			this.type = type;
 		}
 
-		public virtual string GetValue (MemoryStore store, Literal obj)
+		public virtual string GetValue (MemoryStore store, SemWeb.Literal obj)
 		{
 			string result = obj.Value;
 
@@ -139,7 +146,7 @@ namespace FSpot {
 					object o = System.Enum.Parse (type, obj.Value);
 					result = o.ToString ();
 				} catch (System.Exception e) {
-					System.Console.WriteLine ("Value \"{2}\" not found in {0}{3}{1}", type, e, result, System.Environment.NewLine);
+					Log.WarningFormat ("Value \"{2}\" not found in {0}{3}{1}", type, e, result, System.Environment.NewLine);
 				}
 			}
 			/*
@@ -201,7 +208,7 @@ namespace FSpot {
 					if (stream != null) {
 						descriptions.Import (new RdfXmlReader (stream));
 					} else {
-						System.Console.WriteLine ("Can't find resource");
+						Log.Debug ("Can't find resource");
 					}
 				}
 				
@@ -218,7 +225,7 @@ namespace FSpot {
 #endif
 		}
 
-		public static void AddLiteral (StatementSink sink, string predicate, string type, Literal value)
+		public static void AddLiteral (StatementSink sink, string predicate, string type, SemWeb.Literal value)
 		{
 			Entity empty = new BNode ();
 			Statement top = new Statement (FSpotXMPBase, (Entity)MetadataStore.Namespaces.Resolve (predicate), empty);
@@ -237,7 +244,7 @@ namespace FSpot {
 		{
 			Statement stmt = new Statement (FSpotXMPBase,
 							(Entity)MetadataStore.Namespaces.Resolve (predicate), 
-							new Literal (value));
+							new SemWeb.Literal (value));
 			sink.Add (stmt);
 		}
 
@@ -246,6 +253,28 @@ namespace FSpot {
 			Add (sink, FSpotXMPBase, predicate, type, values);
 		}
 
+		public void Delete (string predicate)
+		{
+			System.Collections.ArrayList to_remove = new System.Collections.ArrayList ();
+			foreach (Statement stmt in this) {
+				if (stmt.Predicate == MetadataStore.Namespaces.Resolve (predicate)) {
+					to_remove.Add (stmt);
+					break;
+				}
+			}
+
+			foreach (Statement stmt in to_remove)
+				this.Remove (stmt);
+		}
+
+		public void Update (string predicate, string value1)
+		{
+			// Delete first..
+			Delete (predicate);
+			// Add after...
+			AddLiteral (this, predicate, value1);
+		}
+
 		public void Update (string predicate, string type, string [] values)
 		{
 			Entity anon = null;
@@ -253,7 +282,8 @@ namespace FSpot {
 			System.Collections.ArrayList to_remove = new System.Collections.ArrayList ();
 			foreach (Statement stmt in this) {
 				if (stmt.Predicate == MetadataStore.Namespaces.Resolve (predicate)) {
-					anon = (Entity) stmt.Object;
+					if (type != null) // only look further if we have a type.
+						anon = (Entity) stmt.Object;
 					to_remove.Add (stmt);
 					break;
 				}
@@ -278,7 +308,7 @@ namespace FSpot {
 		public static void Add (StatementSink sink, Entity subject, string predicate, string type, string [] values)
 		{
 			if (values == null) {
-				System.Console.WriteLine ("{0} has no values; skipping", predicate);
+				Log.DebugFormat ("{0} has no values; skipping", predicate);
 				return;
 			}
 
@@ -291,7 +321,7 @@ namespace FSpot {
 			foreach (string value in values) {
 				Statement literal = new Statement (empty,
 								   (Entity)MetadataStore.Namespaces.Resolve ("rdf:li"),
-								   new Literal (value, null, null));
+								   new SemWeb.Literal (value, null, null));
 				sink.Add (literal);
 			}
 			sink.Add (top);
@@ -310,7 +340,7 @@ namespace FSpot {
 				string predicate = stmt.Predicate.ToString ();
 
 				if (predicate.StartsWith (name))
-					System.Console.WriteLine ("----------- {0}", stmt);
+					Log.DebugFormat ("----------- {0}", stmt);
 
 				return true;
 			}
@@ -330,7 +360,7 @@ namespace FSpot {
 		public void DumpNode (XPathSemWebNavigator navi, int depth)
 		{
 			do { 
-				System.Console.WriteLine ("node [{0}] {1} {2}", depth, navi.Name, navi.Value);
+				Log.DebugFormat ("node [{0}] {1} {2}", depth, navi.Name, navi.Value);
 			} while (navi.MoveToNext ());
 		}
 	       
