@@ -1,5 +1,19 @@
+/*
+ * FSpot.PixbufCache.cs
+ *
+ * Author(s):
+ * 	Larry Ewing <lewing@novell.com>
+ *
+ * This is free software. See COPYING for details.
+ */
+
+using System;
 using System.Collections;
 using System.Threading;
+using Hyena;
+
+using FSpot.Utils;
+using FSpot.Platform;
 
 namespace FSpot {
 	public class PixbufCache {
@@ -8,10 +22,6 @@ namespace FSpot {
 		int total_size;
 		int max_size = 256 * 256 * 4 * 30;
 
-		Gtk.ThreadNotify notify;
-		bool  notify_pending;
-		Queue pending;
-
 		private Thread worker;
 
 		public delegate void PixbufLoadedHandler (PixbufCache cache, CacheEntry entry);
@@ -19,45 +29,28 @@ namespace FSpot {
 		
 		public PixbufCache ()
 		{
-			pending = new Queue ();
 			items = new Hashtable ();
 			items_mru = new ArrayList ();
 			
-			notify = new Gtk.ThreadNotify (new Gtk.ReadyEvent (HandleProcessedRequests));
-			
 			worker = new Thread (new ThreadStart (WorkerTask));
 			worker.Start ();
 
-			ThumbnailGenerator.Default.OnPixbufLoaded += HandleThumbnailLoaded;
+			ThumbnailLoader.Default.OnPixbufLoaded += HandleThumbnailLoaded;
 		}
 		
-		public void HandleThumbnailLoaded (PixbufLoader loader, string path, int order, Gdk.Pixbuf result)
+		public void HandleThumbnailLoaded (ImageLoaderThread loader, ImageLoaderThread.RequestItem result)
 		{
-			string thumb_path = ThumbnailGenerator.ThumbnailPath (path);
-			CacheEntry entry;
-			lock (items) {
-				entry = ULookup (thumb_path);
-			}
-
-			if (entry != null && result != null) {
-				int width, height;
-				PixbufUtils.Fit (result, entry.Width, entry.Height, false, out width, out height);
-				Gdk.Pixbuf down = PixbufUtils.ScaleDown (result, width, height);
-				PixbufUtils.CopyThumbnailOptions (result, down);
-				Update (entry, down);
-			}
-
-			//System.Console.WriteLine ("removing {0}", thumb_path);
+            Reload (result.Uri);
 		}
 
-		public void Request (string path, object closure, int width, int height)
+		public void Request (SafeUri uri, object closure, int width, int height)
 		{
 			lock (items) {
-				CacheEntry entry = items[path] as CacheEntry;
+				CacheEntry entry = items[uri] as CacheEntry;
 
 				if (entry == null) {
-					entry = new CacheEntry (this, path, closure, width, height);
-					items [path] = entry;
+					entry = new CacheEntry (this, uri, closure, width, height);
+					items [uri] = entry;
 					items_mru.Add (entry);
 				} else {
 					MoveForward (entry);
@@ -67,16 +60,20 @@ namespace FSpot {
 			}
 		}
 
+//		public void Update (SafeUri uri, Gdk.Pixbuf pixbuf)
+//		{
+//			lock (items) {
+//				CacheEntry entry = (CacheEntry) items [uri];
+//				if (entry != null) {
+//					entry.SetPixbufExtended (pixbuf, true);
+//				}
+//			}
+//		}
+
 		public void Update (CacheEntry entry, Gdk.Pixbuf pixbuf)
 		{
 			lock (items) {
-				lock (entry) {
-					if (entry.Path == null) {
-						pixbuf.Dispose ();
-						return;
-					}
-					entry.Pixbuf = pixbuf;
-				}
+				entry.SetPixbufExtended (pixbuf, true);
 			}
 		}
 		
@@ -93,6 +90,21 @@ namespace FSpot {
 			}
 		}
 
+		public void Reload (SafeUri uri)
+		{
+			CacheEntry entry;
+
+			lock (items) {
+				entry = (CacheEntry) items [uri];
+				if (entry != null) {
+					lock (entry) {
+						entry.Reload = true;
+					}
+					Monitor.Pulse (items);
+				}
+			}
+		}
+
 		private CacheEntry FindNext ()
 		{
 			CacheEntry entry;
@@ -131,7 +143,7 @@ namespace FSpot {
 			int num = 0;
 			while ((items_mru.Count - num) > 10 && total_size > max_size) {
 				CacheEntry entry = (CacheEntry) items_mru [num++];
-				items.Remove (entry.Path);
+				items.Remove (entry.Uri);
 				entry.Dispose ();
 			}
 			if (num > 0) {
@@ -146,23 +158,23 @@ namespace FSpot {
 		private void WorkerTask ()
 		{
 			CacheEntry current = null;
-			ThumbnailGenerator.Default.PushBlock ();
+			//ThumbnailGenerator.Default.PushBlock ();
 			while (true) {
 				try {
 					lock (items) {
 						/* find the next item */
 						while ((current = FindNext ()) == null) {
 							if (!ShrinkIfNeeded ()){
-								ThumbnailGenerator.Default.PopBlock ();
+								//ThumbnailGenerator.Default.PopBlock ();
 								Monitor.Wait (items);
-								ThumbnailGenerator.Default.PushBlock ();
+								//ThumbnailGenerator.Default.PushBlock ();
 							}
 						}
 					}
 					ProcessRequest (current);
 					QueueLast (current);
 				} catch (System.Exception e) {
-					System.Console.WriteLine (e);
+					Log.Exception (e);
 					current = null;
 				}
 			}
@@ -172,9 +184,9 @@ namespace FSpot {
 		{
 			Gdk.Pixbuf loaded = null;
 			try {
-				loaded = new Gdk.Pixbuf (entry.Path);
+				loaded = XdgThumbnailSpec.LoadThumbnail (entry.Uri, ThumbnailSize.Large);
 				this.Update (entry, loaded);
-			} catch (GLib.GException ex){
+			} catch (GLib.GException){
 				if (loaded != null)
 					loaded.Dispose ();
 				return;		
@@ -183,32 +195,12 @@ namespace FSpot {
 		
 		private void QueueLast (CacheEntry entry)
 		{
-			lock (pending) {
-				pending.Enqueue (entry);
-				if (!notify_pending) {
-					notify_pending = true;
-					notify.WakeupMain ();
-				}
-			}
+			Gtk.Application.Invoke (delegate (object obj, System.EventArgs args) {
+				if (entry.Uri != null && OnPixbufLoaded != null)
+					OnPixbufLoaded (this, entry);
+			});
 		}
-
-		private void HandleProcessedRequests ()
-		{
-			Queue entries;
-			lock (pending) {
-				entries = pending.Clone () as Queue;
-				pending.Clear ();
-				notify_pending = false;
-			}
-			
-			if (OnPixbufLoaded != null) {
-				foreach (CacheEntry entry in entries) {
-					if (entry.Path != null)
-						OnPixbufLoaded (this, entry);
-				}
-			}
-		}
-
+		
 		private void MoveForward (CacheEntry entry)
 		{
 #if true
@@ -230,51 +222,51 @@ namespace FSpot {
 		}
 		       
 
-		private CacheEntry ULookup (string path)
+		private CacheEntry ULookup (SafeUri uri)
 		{
-			CacheEntry entry = (CacheEntry) items [path];
+			CacheEntry entry = (CacheEntry) items [uri];
 			if (entry != null) {
 				MoveForward (entry);
 			}
 			return (CacheEntry) entry;
 		}
 
-		public CacheEntry Lookup (string path)
+		public CacheEntry Lookup (SafeUri uri)
 		{
 			lock (items) {
-				return ULookup (path);
+				return ULookup (uri);
 			}
 		}
 
-		public void Remove (string path) 
+		private void URemove (SafeUri uri)
 		{
-			lock (items) {
-				URemove (path);
-			}
-		}
-
-		private void URemove (string path)
-		{
-			CacheEntry entry = (CacheEntry) items [path];
+			CacheEntry entry = (CacheEntry) items [uri];
 			if (entry != null) {
-				items.Remove (path);
+				items.Remove (uri);
 				items_mru.Remove (entry);
 				entry.Dispose ();
 			}
 		}
 
+		public void Remove (SafeUri uri)
+		{
+			lock (items) {
+				URemove (uri);
+			}
+		}
+
 		public class CacheEntry : System.IDisposable {
 			private Gdk.Pixbuf pixbuf;
-			private string path;
+			private SafeUri uri;
 			private int width;
 			private int height;
 			private object data;
 			private bool reload;
 			private PixbufCache cache;
 			
-			public CacheEntry (PixbufCache cache, string path, object closure, int width, int height)
+			public CacheEntry (PixbufCache cache, SafeUri uri, object closure, int width, int height)
 			{
-				this.path = path;
+				this.uri = uri;
 				this.width = width;
 				this.height = height;
 				this.data = closure;
@@ -284,36 +276,22 @@ namespace FSpot {
 			}
 
 			public bool Reload {
-				get {
-					return reload;
-				}
-				set {
-					reload = value;
-				}
+				get { return reload; }
+				set { reload = value; }
 			}
 
-			public string Path {
-				get {
-					return path;
-				}
+			public SafeUri Uri {
+				get { return uri; }
 			}
 
 			public int Width {
-				get {
-					return width;
-				}
-				set {
-					width = value;
-				}
+				get { return width; }
+				set { width = value; }
 			}
 
 			public int Height {
-				get {
-					return height;
-				}
-				set {
-					height = value;
-				}
+				get { return height; }
+				set { height = value; }
 			}
 
 			public object Data {
@@ -329,39 +307,49 @@ namespace FSpot {
 				}
 			}
 			
+			public bool IsDisposed {
+				get { return uri == null; }
+			}
+			
+			public void SetPixbufExtended (Gdk.Pixbuf value, bool ignore_undead)
+			{
+				lock (this) {
+					if (IsDisposed) {
+						if (ignore_undead) {
+							return;
+						} else {
+							throw new System.Exception ("I don't want to be undead");
+						}
+					}							
+
+					Gdk.Pixbuf old = this.Pixbuf;
+					cache.total_size -= this.Size;
+					this.pixbuf = value;
+					if (pixbuf != null) {
+						this.width = pixbuf.Width;
+						this.height = pixbuf.Height;
+					}
+					cache.total_size += this.Size;
+					this.Reload = false;
+					
+					if (old != null)
+						old.Dispose ();
+				}
+			}
+
 			public Gdk.Pixbuf Pixbuf {
 				get {
 					lock (this) {
 						return pixbuf;
 					}
 				}
-				set {
-					lock (this) {
-						if (path == null)
-							throw new System.Exception ("I don't want to be undead");
-
-						Gdk.Pixbuf old = this.Pixbuf;
-						cache.total_size -= this.Size;
-						this.pixbuf = value;
-						if (pixbuf != null) {
-							this.width = pixbuf.Width;
-							this.height = pixbuf.Height;
-						}
-						cache.total_size += this.Size;
-						this.Reload = false;
-
-						if (old != null)
-							old.Dispose ();
-					}
-					
-				}
 			}
 			
 			public Gdk.Pixbuf ShallowCopyPixbuf ()
 			{
 				lock (this) {
-					if (path == null)
-						throw new System.Exception ("I'm dead");
+					if (IsDisposed)
+						return null;
 
 					if (pixbuf == null)
 						return null;
@@ -372,21 +360,25 @@ namespace FSpot {
 			
 			~CacheEntry ()
 			{
-				this.Dispose ();
+				if (!IsDisposed)
+					this.Dispose ();
 			}
 			
 			public void Dispose ()
 			{
 				lock (this) {
-					cache.total_size -= this.Size;
+					if (! IsDisposed)
+						cache.total_size -= this.Size;
+
 					if (this.pixbuf != null) {
 						this.pixbuf.Dispose ();
 						
 					}
 					this.pixbuf = null;
 					this.cache = null;
-					this.path = null;
+					this.uri = null;
 				}
+				System.GC.SuppressFinalize (this);
 			}
 			
 			public int Size {
