@@ -32,6 +32,8 @@ using System.Threading;
 using System.Collections.Generic;
 using Mono.Data.SqliteClient;
 
+using Hyena;
+
 namespace Banshee.Database
 {
     /// <summary>
@@ -52,7 +54,6 @@ namespace Banshee.Database
         private int version;
         private Thread queue_thread;
         private volatile bool dispose_requested = false;
-        private string dbpath;
         private volatile bool connected;
 
         /// <summary>
@@ -80,20 +81,56 @@ namespace Banshee.Database
         /// </summary>
         private AutoResetEvent queue_signal = new AutoResetEvent(false);
         
+	public delegate void ExceptionThrownHandler (Exception e);
+	public event ExceptionThrownHandler ExceptionThrown;
+
         public QueuedSqliteDatabase(string dbpath)
         {
-            this.dbpath = dbpath;
+            // Connect
+            if(connection == null) {
+                version = GetFileVersion(dbpath);
+                if (version == 3) {
+                    connection = new SqliteConnection("Version=3,URI=file:" + dbpath);
+                } else if (version == 2) {
+                    connection = new SqliteConnection("Version=2,encoding=UTF-8,URI=file:" + dbpath);
+                } else {
+                    throw new Exception("Unsupported SQLite database version");
+                }
+                connection.Open();
+                connected = true;
+            }
+ 
             queue_thread = new Thread(ProcessQueue);
             queue_thread.IsBackground = true;
             queue_thread.Start();
         }
+
+        ~QueuedSqliteDatabase ()
+        {
+            Log.DebugFormat ("Finalizer called on {0}. Should be Disposed", GetType ());
+            Dispose (false);
+        }
         
         public void Dispose()
         {
-            dispose_requested = true;
-            queue_signal.Set();
-            queue_thread.Join();
+            Dispose (true);
+            GC.SuppressFinalize (this);
         }
+
+        bool already_disposed = false;
+        protected virtual void Dispose (bool is_disposing)
+        {
+            if (already_disposed)
+                return;
+            if (is_disposing) { //Free managed resources
+                dispose_requested = true;
+                queue_signal.Set();
+                queue_thread.Join();
+            }
+            //Free unmanaged resources
+
+            already_disposed = true;
+       }
         
         private void WaitForConnection()
         {
@@ -135,6 +172,10 @@ namespace Banshee.Database
         {
             return Query(new DbCommand(command.ToString()));
         }
+
+        public bool InTransaction {
+            get { return current_transaction_thread != null; }
+        }
         
         public void BeginTransaction()
         {
@@ -235,20 +276,8 @@ namespace Banshee.Database
 
         private void ProcessQueue()
         {         
-            // Connect
-            if(connection == null) {
-                version = GetFileVersion(dbpath);
-                if (version == 3) {
-                    connection = new SqliteConnection("Version=3,URI=file:" + dbpath);
-                } else if (version == 2) {
-                    connection = new SqliteConnection("Version=2,encoding=UTF-8,URI=file:" + dbpath);
-                } else {
-                    throw new Exception("Unsupported SQLite database version");
-                }
-                connection.Open();
-                connected = true;
-            }
-            
+	    try {
+           
             // Keep handling queries
             while(!dispose_requested) {
                 while(command_queue.Count > 0) {
@@ -256,6 +285,7 @@ namespace Banshee.Database
                     lock(command_queue) {
                         command = command_queue.Dequeue();
                     }
+		    //Log.Debug (command.CommandText);
                     command.Execute();
                 }
 
@@ -264,6 +294,12 @@ namespace Banshee.Database
 
             // Finish
             connection.Close();
+	    } catch (Exception e) {
+		    if (ExceptionThrown != null)
+			    ExceptionThrown (e);
+		    else
+			    throw;
+	    }
         }
 
         public int GetFileVersion(string path) 
@@ -304,6 +340,7 @@ namespace Banshee.Database
         private int insert_id;
         private Exception execution_exception;
         private bool finished = false;
+        private Object finishedLock = new Object();
 
         private SqliteCommand command;
 
@@ -351,6 +388,7 @@ namespace Banshee.Database
                 Thread.Sleep(SLEEP_TIME);
                 Execute();
             } catch(Exception e) {
+                Log.DebugFormat ("Broken query: {0}", command.CommandText);
                 execution_exception = e;
                 if (command_type == Banshee.Database.CommandType.ExecuteNonQuery) {
                     throw execution_exception;
@@ -358,12 +396,19 @@ namespace Banshee.Database
             }
             command.Dispose();
             
+            Monitor.Enter(finishedLock);
             finished = true;
+            Monitor.Pulse(finishedLock);
+            Monitor.Exit(finishedLock);
         }
         
         public object WaitForResult()
         {
-            while(!finished);
+            Monitor.Enter(finishedLock);
+            while (!finished) {
+                Monitor.Wait(finishedLock);
+            };
+            Monitor.Exit(finishedLock);
             
             if(execution_exception != null) {
                 throw execution_exception;
@@ -381,7 +426,7 @@ namespace Banshee.Database
             get { return insert_id; }
         }
         
-        public new CommandType CommandType {
+        public CommandType CommandType {
             get { return command_type; }
             set { command_type = value; }
         }
