@@ -21,6 +21,8 @@ namespace FSpot.Widgets
 	public class ImageView : Container
 	{
 #region public API
+		protected ImageView (IntPtr raw) : base (raw) { }
+
 		public ImageView (Adjustment hadjustment, Adjustment vadjustment, bool can_select) : base ()
 		{
 			OnSetScrollAdjustments (hadjustment, vadjustment);
@@ -207,6 +209,13 @@ namespace FSpot.Widgets
 				GLib.Idle.Add (delegate {scrolled.SetPolicy (Gtk.PolicyType.Automatic, Gtk.PolicyType.Automatic); return false;});
 		}
 
+		bool panning = false;
+		public bool Panning {
+			get {
+				return panning;
+			}
+		}
+
 		public Point WindowCoordsToImage (Point win)
 		{
 			if (Pixbuf == null)
@@ -343,8 +352,8 @@ namespace FSpot.Widgets
 									 Width = Allocation.Width,
 									 Height = Allocation.Height,
 									 Wclass = Gdk.WindowClass.InputOutput,
-									 Visual = this.Visual,
-									 Colormap = this.Colormap,
+									 Visual = ParentWindow.Visual,
+									 Colormap = ParentWindow.Colormap,
 									 Mask = this.Events
 									      | EventMask.ExposureMask
 									      | EventMask.ButtonPressMask
@@ -406,16 +415,6 @@ namespace FSpot.Widgets
 				GdkWindow.MoveResize (allocation.X, allocation.Y, allocation.Width, allocation.Height);
 			}
 
-			Hadjustment.PageSize = Math.Min (scaled_width, allocation.Width);
-			Hadjustment.PageIncrement = scaled_width * .9;
-			Hadjustment.StepIncrement = 32;
-			Hadjustment.Lower = 0;
-
-			Vadjustment.PageSize = Math.Min (scaled_height, allocation.Height);
-			Vadjustment.PageIncrement = scaled_height * .9;
-			Vadjustment.StepIncrement = 32;
-			Vadjustment.Lower = 0;
-
 			if (XOffset > Hadjustment.Upper - Hadjustment.PageSize)
 				ScrollTo ((int)(Hadjustment.Upper - Hadjustment.PageSize), YOffset, false);
 			if (YOffset > Vadjustment.Upper - Vadjustment.PageSize)
@@ -479,37 +478,20 @@ namespace FSpot.Widgets
 				HandleAdjustmentsValueChanged (this, EventArgs.Empty);
 		}	
 
-//		bool dragging = false;
-//		int draganchor_x = 0;
-//		int draganchor_y = 0;
 		protected override bool OnButtonPressEvent (EventButton evnt)
 		{
 			bool handled = false;
+
 			if (!HasFocus)
 				GrabFocus ();
 
 			if (PointerMode == PointerMode.None)
 				return false;
 
+			handled = handled || OnPanButtonPressEvent (evnt);
+
 			if (can_select)
-				handled |= OnSelectionButtonPressEvent (evnt);
-
-			if (handled)
-				return handled;
-
-	//		if (dragging)
-	//			return base.OnButtonPressEvent (evnt);
-
-	//		switch (evnt.Button) {
-	//		case 1:	
-	//			dragging = true;
-	//			draganchor_x = (int)evnt.X;
-	//			draganchor_y = (int)evnt.Y;
-
-	//			handled = true;
-	//		default:
-	//			break;
-	//		}
+				handled = handled || OnSelectionButtonPressEvent (evnt);
 
 			return handled || base.OnButtonPressEvent (evnt);
 		}
@@ -518,21 +500,22 @@ namespace FSpot.Widgets
 		{
 			bool handled = false;
 
+			handled = handled || OnPanButtonReleaseEvent (evnt);
+
 			if (can_select)
-				handled |= OnSelectionButtonReleaseEvent (evnt);
+				handled = handled || OnSelectionButtonReleaseEvent (evnt);
 
-			if (handled)
-				return handled;
-
-			return handled |= base.OnButtonReleaseEvent (evnt);
+			return handled || base.OnButtonReleaseEvent (evnt);
 		}
 
 		protected override bool OnMotionNotifyEvent (EventMotion evnt)
 		{
 			bool handled = false;
 
+			handled = handled || OnPanMotionNotifyEvent (evnt);
+
 			if (can_select)
-				handled |= OnSelectionMotionNotifyEvent (evnt);
+				handled = handled || OnSelectionMotionNotifyEvent (evnt);
 
 			return handled || base.OnMotionNotifyEvent (evnt);
 
@@ -770,8 +753,18 @@ namespace FSpot.Widgets
 				scaled_height = (uint)Math.Floor (height * Zoom + .5);
 			}
 
+			Hadjustment.PageSize = Math.Min (scaled_width, Allocation.Width);
+			Hadjustment.PageIncrement = scaled_width * .9;
+			Hadjustment.StepIncrement = 32;
 			Hadjustment.Upper = scaled_width;
+			Hadjustment.Lower = 0;
+
+			Vadjustment.PageSize = Math.Min (scaled_height, Allocation.Height);
+			Vadjustment.PageIncrement = scaled_height * .9;
+			Vadjustment.StepIncrement = 32;
 			Vadjustment.Upper = scaled_height;
+			Vadjustment.Lower = 0;
+
 		}
 
 		event EventHandler AdjustmentsChanged;
@@ -992,7 +985,7 @@ namespace FSpot.Widgets
 		void SelectionSetPointer (int x, int y)
 		{
 			if (is_moving_selection)
-				GdkWindow.Cursor = new Cursor (CursorType.Fleur);
+				GdkWindow.Cursor = new Cursor (CursorType.Crosshair);
 			else {
 				switch (GetDragMode (x, y)) {
 				case DragMode.Move:
@@ -1031,6 +1024,7 @@ namespace FSpot.Widgets
 			
 		}
 
+
 		const int SELECTION_THRESHOLD = 5;
 		bool OnSelectionMotionNotifyEvent (EventMotion evnt)
 		{
@@ -1116,5 +1110,65 @@ namespace FSpot.Widgets
 					      width, height);
 		}
 #endregion
+
+#region panning
+		Point pan_anchor = new Point (0, 0);
+
+		bool OnPanButtonPressEvent (EventButton evnt)
+		{
+			if (2 != evnt.Button) {
+				return false;
+			}
+
+			System.Diagnostics.Debug.Assert (!panning);
+			panning = true;
+
+			pan_anchor.X = (int) evnt.X;
+			pan_anchor.Y = (int) evnt.Y;
+
+			PanSetPointer ();
+
+			return true;
+		}
+
+		bool OnPanMotionNotifyEvent (EventMotion evnt)
+		{
+			if (!panning) {
+				return false;
+			}
+
+			int pan_x = pan_anchor.X - (int) evnt.X;
+			int pan_y = pan_anchor.Y - (int) evnt.Y;
+			ScrollBy (pan_x, pan_y);
+
+			pan_anchor.X = (int) evnt.X;
+			pan_anchor.Y = (int) evnt.Y;
+
+			PanSetPointer ();
+
+			return true;
+		}
+
+		bool OnPanButtonReleaseEvent (EventButton evnt)
+		{
+			if (2 != evnt.Button) {
+				return false;
+			}
+
+			System.Diagnostics.Debug.Assert (panning);
+			panning = false;
+
+			PanSetPointer ();
+
+			return true;
+		}
+
+		void PanSetPointer ()
+		{
+			GdkWindow.Cursor = panning
+					? new Cursor (CursorType.Fleur)
+					: null;
+		}
+#endregion
 	}
 }
