@@ -7,7 +7,7 @@
  * 	Gabriel Burt
  *	Stephane Delcroix  <stephane@delcroix.org>
  *	Ruben Vermeersch <ruben@savanne.be>
- *  Mike Gemuende <mike@gemuende.de>
+ *	Mike Gemuende <mike@gemuende.de>
  *
  * This is free software. See COPYING for details.
  */
@@ -23,6 +23,7 @@ using FSpot.Utils;
 using GLib;
 using GFile = GLib.File;
 using GFileInfo = GLib.FileInfo;
+using Hyena;
 
 // FIXME TODO: We want to use something like EClippedLabel here throughout so it handles small sizes
 // gracefully using ellipsis.
@@ -144,7 +145,7 @@ namespace FSpot.Widgets
 
 		private void HandleRatingChanged (object o, EventArgs e)
 		{
-			MainWindow.Toplevel.HandleRatingMenuSelected ((o as Widgets.Rating).Value);
+			App.Instance.Organizer.HandleRatingMenuSelected ((o as Widgets.Rating).Value);
 	 	}
 	
 		private Label CreateRightAlignedLabel (string text)
@@ -184,17 +185,18 @@ namespace FSpot.Widgets
 				ContextSwitchStrategy.SetHistogramVisible (Context, histogram_expander.Expanded);
 				UpdateHistogram ();
 			};
+			histogram_expander.StyleSet += delegate (object sender, StyleSetArgs args) { 
+				Gdk.Color c = this.Toplevel.Style.Backgrounds [(int)Gtk.StateType.Active];
+				histogram.RedColorHint = (byte) (c.Red / 0xff);
+				histogram.GreenColorHint = (byte) (c.Green / 0xff);
+				histogram.BlueColorHint = (byte) (c.Blue / 0xff);
+				histogram.BackgroundColorHint = 0xff;
+				UpdateHistogram ();
+			};
 			histogram_image = new Gtk.Image ();
 			histogram = new Histogram ();
 			histogram_expander.Add (histogram_image);
 
-			Window window = MainWindow.Toplevel.Window;
-			Gdk.Color c = window.Style.Backgrounds [(int)Gtk.StateType.Active];
-			histogram.RedColorHint = (byte) (c.Red / 0xff);
-			histogram.GreenColorHint = (byte) (c.Green / 0xff);
-			histogram.BlueColorHint = (byte) (c.Blue / 0xff);
-			histogram.BackgroundColorHint = 0xff;
-
 			Add (histogram_expander);
 
 			info_expander = new Expander (Catalog.GetString ("Image Information"));
@@ -274,7 +276,7 @@ namespace FSpot.Widgets
 			rating_view.Changed += HandleRatingChanged;
 			rating_align.Add (rating_view);
 
-			tag_view = new TagView (MainWindow.ToolTips);
+			tag_view = new TagView ();
 			info_table.Attach (tag_view, 0, 2, 9, 10, AttachOptions.Fill, AttachOptions.Fill, TABLE_XPADDING, TABLE_YPADDING);
 
 			info_table.ShowAll ();
@@ -337,7 +339,7 @@ namespace FSpot.Widgets
 					height = real_height.ToString ();
 				}
 	#if USE_EXIF_DATE
-				date = img.Date.ToLocalTime ();
+				date = img.Date;
 	#endif
 			}
 	
@@ -468,8 +470,10 @@ namespace FSpot.Widgets
 			if (Photos == null || Photos.Length == 0) {
 				Hide ();
 			} else if (Photos.Length == 1) {
+				Show ();
 				UpdateSingle ();
 			} else if (Photos.Length > 1) {
+				Show ();
 				UpdateMultiple ();
 			}
 			return false;
@@ -492,13 +496,13 @@ namespace FSpot.Widgets
 			
 			try {
 				//using (new Timer ("building info")) {
-					using (ImageFile img = ImageFile.Create (photo.DefaultVersionUri))
+					using (ImageFile img = ImageFile.Create (photo.DefaultVersion.Uri))
 					{
 						info = new ImageInfo (img);
 					}
 					//}
 			} catch (System.Exception e) {
-				FSpot.Utils.Log.Debug (e.StackTrace);
+				Hyena.Log.Debug (e.StackTrace);
 				info = new ImageInfo (null);			
 			}
 
@@ -521,7 +525,7 @@ namespace FSpot.Widgets
 	#if USE_EXIF_DATE
 				date_value_label.Text = info.Date;
 	#else
-				DateTime local_time = photo.Time.ToLocalTime ();
+				DateTime local_time = photo.Time;
 				date_value_label.Text = String.Format ("{0}{2}{1}",
 				                                       local_time.ToShortDateString (),
 				                                       local_time.ToShortTimeString (),
@@ -546,25 +550,33 @@ namespace FSpot.Widgets
 			version_combo.Visible = true;
 			version_list.Clear ();
 			version_combo.Changed -= OnVersionComboChanged;
-			int i = 0;
-			foreach (uint version_id in photo.VersionIds) {
-				version_list.AppendValues (version_id, (photo.GetVersion (version_id) as PhotoVersion).Name, true);
-				if (version_id == photo.DefaultVersionId)
-					version_combo.Active = i;
-				i++;
+			
+			bool hasVersions = photo.VersionIds.Length > 1;
+			version_combo.Sensitive = hasVersions;
+			if (hasVersions) {
+				int i = 0;
+				foreach (uint version_id in photo.VersionIds) {
+					version_list.AppendValues (version_id, (photo.GetVersion (version_id) as PhotoVersion).Name, true);
+					if (version_id == photo.DefaultVersionId)
+						version_combo.Active = i;
+					i++;
+				}
+				version_combo.TooltipText = String.Format (Catalog.GetPluralString ("(One Edit)", "({0} Edits)", i - 1), i - 1);
+			} else {
+				version_list.AppendValues (photo.DefaultVersionId, photo.DefaultVersion.Name + " " + Catalog.GetString ("(No Edits)"), true);
+				version_combo.Active = 0;
+				version_combo.TooltipText = Catalog.GetString ("(No Edits)");
 			}
-			if (photo.VersionIds.Length == 1)
-				version_list.AppendValues ((uint)0, Catalog.GetString ("(No Edits)"), false);
 			version_combo.Changed += OnVersionComboChanged;
 
 			if (show_file_size) {
 				try {
-					GFile file = FileFactory.NewForUri (photo.DefaultVersionUri);
+					GFile file = FileFactory.NewForUri (photo.DefaultVersion.Uri);
 					GFileInfo file_info = file.QueryInfo ("standard::size", FileQueryInfoFlags.None, null);
 					file_size_value_label.Text = Format.SizeForDisplay (file_info.Size);
 				} catch (GLib.GException e) {
 					file_size_value_label.Text = Catalog.GetString("(File read error)");
-					FSpot.Utils.Log.DebugException (e);
+					Hyena.Log.DebugException (e);
 				}
 			}
 			
@@ -629,29 +641,29 @@ namespace FSpot.Widgets
 				if (first.Time.Date == last.Time.Date) {
 					//Note for translators: {0} is a date, {1} and {2} are times.
 					date_value_label.Text = String.Format(Catalog.GetString("On {0} between \n{1} and {2}"), 
-					                                      first.Time.ToLocalTime ().ToShortDateString (),
-					                                      first.Time.ToLocalTime ().ToShortTimeString (),
-					                                      last.Time.ToLocalTime ().ToShortTimeString ());
+					                                      first.Time.ToShortDateString (),
+					                                      first.Time.ToShortTimeString (),
+					                                      last.Time.ToShortTimeString ());
 				} else {
 					date_value_label.Text = String.Format(Catalog.GetString("Between {0} \nand {1}"),
-					                                      first.Time.ToLocalTime ().ToShortDateString (),
-					                                      last.Time.ToLocalTime ().ToShortDateString ());
+					                                      first.Time.ToShortDateString (),
+					                                      last.Time.ToShortDateString ());
 				}
 			}
 			date_label.Visible = show_date;
 			date_value_label.Visible = show_date;
-			
+
 			if (show_file_size) {
 				long file_size = 0;
 				foreach (Photo photo in Photos) {
 					
 					try {
-						GFile file = FileFactory.NewForUri (photo.DefaultVersionUri);
+						GFile file = FileFactory.NewForUri (photo.DefaultVersion.Uri);
 						GFileInfo file_info = file.QueryInfo ("standard::size", FileQueryInfoFlags.None, null);
 						file_size += file_info.Size;
 					} catch (GLib.GException e) {
 						file_size = -1;
-						FSpot.Utils.Log.DebugException (e);
+						Hyena.Log.DebugException (e);
 						break;
 					}
 				}
@@ -697,14 +709,14 @@ namespace FSpot.Widgets
 
 			try {
 				if (hint == null)
-					using (ImageFile img = ImageFile.Create (photo.DefaultVersionUri))
+					using (ImageFile img = ImageFile.Create (photo.DefaultVersion.Uri))
 						hint = img.Load (256, 256);
 				
 				histogram_image.Pixbuf = histogram.Generate (hint, max);
 				
 				hint.Dispose ();
 			} catch (System.Exception e) {
-				FSpot.Utils.Log.Debug (e.StackTrace);
+				Hyena.Log.Debug (e.StackTrace);
 				using (Gdk.Pixbuf empty = new Gdk.Pixbuf (Gdk.Colorspace.Rgb, true, 8, 256, 256)) {
 					empty.Fill (0x0);
 					histogram_image.Pixbuf = histogram.Generate (empty, max);
@@ -738,7 +750,7 @@ namespace FSpot.Widgets
 	
 		public void HandleMainWindowViewModeChanged (object o, EventArgs args)
 		{
-			MainWindow.ModeType mode = MainWindow.Toplevel.ViewMode;
+			MainWindow.ModeType mode = App.Instance.Organizer.ViewMode;
 			if (mode == MainWindow.ModeType.IconView)
 				Context = ViewContext.Library;
 			else if (mode == MainWindow.ModeType.PhotoView)
